# frozen_string_literal: true

#
# Cookbook Name:: snu-sumologic
# Library:: resource/snu_sumo_source_local_file
#
# Copyright (C) 2014-2017, Socrata, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

class Chef
  class Resource
    # A more opinionated version of the sumo_source_local_file custom resource
    # that replaces some of its default properties with our own.
    #
    # @author Jonathan Hartman <jonathan.hartman@socrata.com>
    class SnuSumoSourceLocalFile < SumoSourceLocalFile
      actions :create, :delete

      # Set the default JSON directory.
      attribute :source_json_directory,
                kind_of: String,
                required: true,
                default: '/etc/sumo.d'

      # Default the time zone to UTC and make forcing it the default.
      attribute :time_zone, kind_of: String, default: 'UTC'
      attribute :force_time_zone,
                kind_of: [TrueClass, FalseClass],
                default: true
    end
  end
end
